==> com.liferay.portal.search.admin.web-2.0.57-sources.jar: com/liferay/portal/search/admin/web/internal/display/context/FieldMappingsDisplayContext.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.portal.search.admin.web.internal.display.context;

import java.util.List;

/**
 * @author Adam Brandizzi
 */
public class FieldMappingsDisplayContext {

	public List<FieldMappingIndexDisplayContext>
		getFieldMappingIndexDisplayContexts() {

		return _fieldMappingIndexDisplayContexts;
	}

	public String getFieldMappings() {
		return _fieldMappings;
	}

	public List<String> getIndexNames() {
		return _indexNames;
	}

	public String getSelectedIndexName() {
		return _selectedIndexName;
	}

	public void setFieldMappingIndexDisplayContexts(
		List<FieldMappingIndexDisplayContext>
			fieldMappingIndexDisplayContexts) {

		_fieldMappingIndexDisplayContexts = fieldMappingIndexDisplayContexts;
	}

	public void setFieldMappings(String fieldMappings) {
		_fieldMappings = fieldMappings;
	}

	public void setIndexNames(List<String> indexNames) {
		_indexNames = indexNames;
	}

	public void setSelectedIndexName(String selectedIndexName) {
		_selectedIndexName = selectedIndexName;
	}

	private List<FieldMappingIndexDisplayContext>
		_fieldMappingIndexDisplayContexts;
	private String _fieldMappings;
	private List<String> _indexNames;
	private String _selectedIndexName;

}

==> com.liferay.portal.search.admin.web-3.0.42-sources.jar: com/liferay/portal/search/admin/web/internal/display/context/FieldMappingsDisplayContext.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.portal.search.admin.web.internal.display.context;

import java.util.List;
import java.util.Map;

/**
 * @author Adam Brandizzi
 */
public class FieldMappingsDisplayContext {

	public Map<String, Object> getData() {
		return _data;
	}

	public List<FieldMappingIndexDisplayContext>
		getFieldMappingIndexDisplayContexts() {

		return _fieldMappingIndexDisplayContexts;
	}

	public String getFieldMappings() {
		return _fieldMappings;
	}

	public List<String> getIndexNames() {
		return _indexNames;
	}

	public String getSelectedIndexName() {
		return _selectedIndexName;
	}

	public void setData(Map<String, Object> data) {
		_data = data;
	}

	public void setFieldMappingIndexDisplayContexts(
		List<FieldMappingIndexDisplayContext>
			fieldMappingIndexDisplayContexts) {

		_fieldMappingIndexDisplayContexts = fieldMappingIndexDisplayContexts;
	}

	public void setFieldMappings(String fieldMappings) {
		_fieldMappings = fieldMappings;
	}

	public void setIndexNames(List<String> indexNames) {
		_indexNames = indexNames;
	}

	public void setSelectedIndexName(String selectedIndexName) {
		_selectedIndexName = selectedIndexName;
	}

	private Map<String, Object> _data;
	private List<FieldMappingIndexDisplayContext>
		_fieldMappingIndexDisplayContexts;
	private String _fieldMappings;
	private List<String> _indexNames;
	private String _selectedIndexName;

}
